<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>AbortedByUserError</name>
    <message>
        <location filename="src/errors.py" line="43"/>
        <source>The user aborted the current action.</source>
        <translation>Uporabnik je prekinil trenutno aktivnost.</translation>
    </message>
</context>
<context>
    <name>ContentError</name>
    <message>
        <location filename="src/errors.py" line="55"/>
        <source>Could not open file because its contents are invalid, or written in a way not supported by OpenTeacher.</source>
        <translation>Datoteke ni mogoče odpreti zaradi njene neveljavne vsebine ali pa je vsebina napisana na način, ki ga OpenTeacher ne podpira.</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="ui/about.ui" line="14"/>
        <source>About OpenTeacher</source>
        <translation>O OpenTeacher</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="28"/>
        <source>About</source>
        <translation>Vizitka</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="106"/>
        <source>License</source>
        <translation>Licneca</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="169"/>
        <source>Full license text</source>
        <translation>Celotno besedilo licence</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="195"/>
        <source>Authors</source>
        <translation>Avtorji</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="208"/>
        <source>Name</source>
        <translation>Naziv</translation>
    </message>
    <message>
        <location filename="ui/wrtsLogin.ui" line="13"/>
        <source>WRTS - login please:</source>
        <translation>WRTS - prosimo, prijavite se:</translation>
    </message>
    <message>
        <location filename="ui/wrtsLogin.ui" line="22"/>
        <source>E-mail</source>
        <translation>Elektronska pošta</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="199"/>
        <source>Password:</source>
        <translation>Geslo:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="14"/>
        <source>OpenTeacher - Settings</source>
        <translation>OpenTeacher - Nastavitve</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="24"/>
        <source>General</source>
        <translation>Splošno</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="32"/>
        <source>Language:</source>
        <translation>Jezik:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="44"/>
        <source>Show &apos;overwrite&apos;-dialogs</source>
        <translation>Pokaži &apos;prepiši&apos; dialoge</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="57"/>
        <source>Show &apos;do you want to save&apos;-dialogs</source>
        <translation>Pokaži &apos;ali želite shraniti&apos; dialoge</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="70"/>
        <source>Lesson</source>
        <translation>Lekcija</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="76"/>
        <source>Show &apos;stop lesson&apos;-dialogs</source>
        <translation>Pokaži &apos;ustavi lekcijo&apos; dialoge</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="86"/>
        <source>Show &apos;lesson completed&apos;-dialogs</source>
        <translation>Pokaži &apos;lekcija zaključena&apos; dialoge</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="98"/>
        <source>Fade duration when wrong:</source>
        <translation>Čas pojemanja ob napačnem odgovoru</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="155"/>
        <source>milliseconds</source>
        <translation>milisekunde</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="133"/>
        <source>Repeat mode hint duration:</source>
        <translation>Čas ponavljanja namiga:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="168"/>
        <source>Note notation:</source>
        <translation>Zabeleži opombo:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="183"/>
        <source>WRTS</source>
        <translation>WRTS</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="189"/>
        <source>Username:</source>
        <translation>Uporabniško ime:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="213"/>
        <source>Try to connect to WRTS</source>
        <translation>Poskusi se povezati na WRTS</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="216"/>
        <source>Thanks to all Launchpad contributors!</source>
        <translation>Hvala vsem prispevajočim na Launchpad-u!</translation>
    </message>
    <message>
        <location filename="ui/wrtsListChoice.ui" line="14"/>
        <source>Choose WRTS list:</source>
        <translation>Izberite WRTS seznam:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="230"/>
        <source>Special Characters</source>
        <translation>Posebni znaki</translation>
    </message>
</context>
<context>
    <name>DocumentationDialog</name>
    <message>
        <location filename="src/openteacher.py" line="356"/>
        <source>Documentation</source>
        <translation>Dokumentacija</translation>
    </message>
</context>
<context>
    <name>InputEmptyError</name>
    <message>
        <location filename="src/errors.py" line="59"/>
        <source>There seems to be no content in the input area</source>
        <translation>Izgleda, da ni vsebine za to področje</translation>
    </message>
</context>
<context>
    <name>InputFormatError</name>
    <message>
        <location filename="src/errors.py" line="63"/>
        <source>There seems to be something wrong with the default input formatting (question = answer)</source>
        <translation>Izgleda, da je nekaj narobe s privzetim vhodnim izpisom (vprašanje = odgovor)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="ui/openteacher.ui" line="14"/>
        <source>OpenTeacher</source>
        <translation>OpenTeacher</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="38"/>
        <source>Enter list</source>
        <translation>Vnesite seznam</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="68"/>
        <source>Title:</source>
        <translation>Naslov</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="81"/>
        <source>Question Language:</source>
        <translation>Jezik vprašanja:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="94"/>
        <source>Answer Language:</source>
        <translation>Jezik odgovora:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="874"/>
        <source>Symbols</source>
        <translation>Simboli</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="915"/>
        <source>Greek</source>
        <translation>Grško</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="269"/>
        <source>Click here to enter the words in the textfield into the wordlisttable.</source>
        <translation>Kliknite tukaj, da  besede, ki so v besedilnem polju, vnesete v tabelo seznama besed.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="272"/>
        <source>Enter!</source>
        <translation>Vstopi!</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="275"/>
        <source>Ctrl+Return</source>
        <translation>Ctrl+Vrni</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="297"/>
        <source>Remove selected row(s)</source>
        <translation>Odstrani izbrane vrstice</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="300"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="330"/>
        <source>Teach me!</source>
        <translation>Nauči me!</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="357"/>
        <source>Question Order:</source>
        <translation>Vrstni red vprašanj:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="365"/>
        <source>Known-Foreign</source>
        <translation>Znan-Tuj</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="370"/>
        <source>Foreign-Known</source>
        <translation>Tuj-Znan</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="378"/>
        <source>Lesson Type:</source>
        <translation>Tip lekcije:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="386"/>
        <source>Ask smart (ideal for practising)</source>
        <translation>Pametno sprašuj (idealno za vajo)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="396"/>
        <source>Ask until all answered right</source>
        <translation>Sprašuj, dokkler niso vsi odgovori pravilni</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="401"/>
        <source>Ask all once</source>
        <translation>Vprašaj vse naenkrat</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="409"/>
        <source>Lesson Order:</source>
        <translation>Vrstni red lekcij</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="417"/>
        <source>Random</source>
        <translation>Naključno</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="422"/>
        <source>Normal</source>
        <translation>Običajno</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="427"/>
        <source>Reverse</source>
        <translation>V nasprotno smer</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="432"/>
        <source>Sorted (ascending)</source>
        <translation>Razvrščeno (naraščajoče)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="437"/>
        <source>Sorted (descending)</source>
        <translation>Razvrščeno (padajoče)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="445"/>
        <source>Ask Words:</source>
        <translation>Vprašaj besedo:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="453"/>
        <source>All</source>
        <translation>Vsi</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="458"/>
        <source>Words you never answered correctly</source>
        <translation>Besede, ki jih nikoli niste prevedli pravilno</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="463"/>
        <source>Hard Words (&gt;50% errors)</source>
        <translation>Težje besede (&gt;50% napak)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="508"/>
        <source>Word:</source>
        <translation>Beseda:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="564"/>
        <source>Type Answer</source>
        <translation>Natipkajte odgovor</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="815"/>
        <source>Translation:</source>
        <translation>Prevod:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="785"/>
        <source>Click here to check if your answer is right.</source>
        <translation>Kliknite sem, da preverite, če ste prevedli pravilno.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="788"/>
        <source>Check!</source>
        <translation>Preveri!</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="791"/>
        <source>Return</source>
        <translation>Vrni</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="798"/>
        <source>Click here to correct the last checked answer anyway.</source>
        <translation>Kliknite, da popravite zadnji preverjen odgovor.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="801"/>
        <source>Correct anyway</source>
        <translation>Vseeno popravi</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="644"/>
        <source>Click here to view the answer of the current showed question.</source>
        <translation>Kliknite tukaj, da preverite odgovor trenutno prikazujočega vprašanja.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="647"/>
        <source>View answer</source>
        <translation>Poglej odgovor</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="660"/>
        <source>Click here if the answer matches to what you were thinking.</source>
        <translation>Klikni tukaj, če se odgovor ujema s tem, kar si mislil.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="663"/>
        <source>I was right</source>
        <translation>Imel sem prav</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="670"/>
        <source>Click here if the answer doesn&apos;t match with what you were thinking.</source>
        <translation>Klikni tukaj, če se odgovor ni ujemal z mojim razmišljanjem.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="673"/>
        <source>I was wrong</source>
        <translation>Nisem imel prav</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="681"/>
        <source>Shuffle answer</source>
        <translation>Premešaj odgovore</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="766"/>
        <source>Hint:</source>
        <translation>Namig:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="755"/>
        <source>Repeat answer</source>
        <translation>Ponovi odgovor</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="808"/>
        <source>Start!</source>
        <translation>Začni!</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1022"/>
        <source>Total Questions:</source>
        <translation>Vsa vprašanja:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1057"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1036"/>
        <source>Right Answers:</source>
        <translation>Pravilni odgovori:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1050"/>
        <source>Note:</source>
        <translation>Opomba:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1093"/>
        <source>File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1097"/>
        <source>&amp;Export</source>
        <translation>&amp;Izvozi</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1107"/>
        <source>Import</source>
        <translation>Uvozi</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1130"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1137"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1148"/>
        <source>toolBar</source>
        <translation>Orodna vrstica</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1175"/>
        <source>&amp;Open</source>
        <translation>&amp;Odpri</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1178"/>
        <source>Open an existing file.</source>
        <translation>Odpri v obstoječi datoteki.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1181"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1190"/>
        <source>&amp;Save</source>
        <translation>&amp;Shrani</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1193"/>
        <source>Save the current opened file.</source>
        <translation>Shrani trenutno odprto datoteko.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1196"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1205"/>
        <source>&amp;Quit</source>
        <translation>&amp;Končaj</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1208"/>
        <source>Close OpenTeacher.</source>
        <translation>Zapri OpenTeacher.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1211"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1220"/>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1223"/>
        <source>View information about OpenTeacher.</source>
        <translation>Poglej informacije o OpenTeacher</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1232"/>
        <source>Save &amp;As</source>
        <translation>Shrani &amp;kot</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1235"/>
        <source>Save the current opened file under a different name.</source>
        <translation>Shrani trenutno odprto datoteko pod drugo ime.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1238"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1247"/>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1250"/>
        <source>New</source>
        <translation>Nov</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1253"/>
        <source>Open a new, empty file.</source>
        <translation>Odpri v novi, prazni datoteki.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1256"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1277"/>
        <source>WRTS (online)</source>
        <translation>WRTS (povezan na spletu)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1268"/>
        <source>Import a wordlist from your online WRTS-account.</source>
        <translation>Uvozite seznam besed iz vašega spletnega WRTS računa.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1280"/>
        <source>Export the current opened wordlist to your online WRTS-account.</source>
        <translation>Izvozite trenutno odprt seznam besed v vaš spletni WRTS račun.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1292"/>
        <source>Print the current opened file.</source>
        <translation>Natisnite trenutno odprto datoteko.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1295"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1304"/>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="956"/>
        <source>Cyrillic</source>
        <translation>Cirilica</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1289"/>
        <source>&amp;Print</source>
        <translation>&amp;Natisni</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1313"/>
        <source>&amp;Documentation</source>
        <translation>&amp;Dokumentacija</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="391"/>
        <source>Interval training</source>
        <translation>Časovni razmik vadenja</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1316"/>
        <source>Documentation</source>
        <translation>Dokumentacija</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="844"/>
        <source>Change lesson settings</source>
        <translation>Spremenite nastavitve lekcije</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="484"/>
        <source>Back to the lesson</source>
        <translation>Nazaj na lekcijo.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="294"/>
        <source>Click here to remove the selected row(s) from the word list table.</source>
        <translation>Kliknite sem za odstranitev vrstic(e) iz preglednice seznama besed.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="628"/>
        <source>Think answer</source>
        <translation>Premislite odgovor</translation>
    </message>
</context>
<context>
    <name>NoEqualsSignInInputError</name>
    <message>
        <location filename="src/errors.py" line="79"/>
        <source>One or more lines could not be added (did they contain a = character?)</source>
        <translation>Ena ali več vrstic ne more biti dodanih (ali vsebujejo a = znak?)</translation>
    </message>
</context>
<context>
    <name>NoWordsEnteredError</name>
    <message>
        <location filename="src/errors.py" line="91"/>
        <source>You didn&apos;t enter any words! Enter them and try again.</source>
        <translation>Niste vnesli nobene besede. Vnesite jih in poskusite kasneje.</translation>
    </message>
</context>
<context>
    <name>NoWordsLeftError</name>
    <message>
        <location filename="src/errors.py" line="87"/>
        <source>After filtering the wordlist, no words where left. Adjust the filter.</source>
        <translation>Po filtriranju seznama besed ni ostalo nobene besede. Prilagodite filter.</translation>
    </message>
</context>
<context>
    <name>NotEnoughMetadataError</name>
    <message>
        <location filename="src/errors.py" line="75"/>
        <source>Please fill in the wordlist title, question language and answer language first. Then try again.</source>
        <translation>Prosimo, najprej dopolnite naslov, jezik vprašanj in jezik odgovorov v seznam besed. Potem poskusite ponovno.</translation>
    </message>
</context>
<context>
    <name>OpenError</name>
    <message>
        <location filename="src/errors.py" line="51"/>
        <source>Could not open file. Please check that you have permission to read this file.</source>
        <translation>Ni mogoče odpreti datoteke. Prosimo, preverite, če imate dovoljenje za branje te datoteke.</translation>
    </message>
</context>
<context>
    <name>OpenTeacher</name>
    <message>
        <location filename="src/openteacher.py" line="220"/>
        <source>Code</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="225"/>
        <source>Localisation</source>
        <translation>Lokalizacija</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="319"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1250"/>
        <source>No selection was detected.</source>
        <translation>Nobena izbira ni bila odkrita.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1530"/>
        <source>Correct answer</source>
        <translation>Pravilni odgovor</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1625"/>
        <source>Translation: </source>
        <translation>Prevod:</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1634"/>
        <source>Think about the answer, and press the &apos;View answer&apos; button when you&apos;re done.</source>
        <translation>Razmislite o odgovoru in potem kliknite &apos;Poglej odgovor&apos; gumb, ko boste končali.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1733"/>
        <source>Hint:</source>
        <translation>Namig</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1726"/>
        <source>Click the button to start.</source>
        <translation>Kluknite na gumb za začetek.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1788"/>
        <source>Test completed!</source>
        <translation>Preizkus je končan!</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1788"/>
        <source>Test completed! Your note:</source>
        <translation>Preizkus je končan! Vaši zaznamki:</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1940"/>
        <source>Message</source>
        <translation>Sporočilo</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1940"/>
        <source>Do you want to save changes?</source>
        <translation>Želite shraniti spremembe?</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1960"/>
        <source>Exit lesson</source>
        <translation>Izhod iz lekcije</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1960"/>
        <source>Are you sure you want to stop the lesson?</source>
        <translation>Ste prepričani, da želite zaključiti lekcijo?</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2004"/>
        <source>Supported</source>
        <translation>Podprto</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2083"/>
        <source>Plain text</source>
        <translation>Golo besedilo</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2098"/>
        <source>Save...</source>
        <translation>Shrani ...</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2240"/>
        <source>Print Document</source>
        <translation>Natisni dokument</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2292"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="267"/>
        <source>OpenTeacher authors</source>
        <translation>Avtorji OpenTeacher</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1211"/>
        <source>The word(s) were entered successfully.</source>
        <translation>Besede so bile uspešno vnešene.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1247"/>
        <source>The word(s) were removed successfully.</source>
        <translation>Besede so bile uspešno odstranjene.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1888"/>
        <source>The wordlist from WRTS was imported successfully.</source>
        <translation>Seznam besed iz WRTS je bil uspešno uvožen.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1918"/>
        <source>Export successful</source>
        <translation>Izvoz je bil uspešeno opravljen</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1919"/>
        <source>Word list exported to WRTS.</source>
        <translation>Seznam besed je bil izvožen v WRTS.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1994"/>
        <source>New file created.</source>
        <translation>Ustvarjena je bila nova datoteka.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2022"/>
        <source>The selected file was opened successfully.</source>
        <translation>Izbrane datoteke so bile uspešno odprte.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2165"/>
        <source>File saved.</source>
        <translation>Datoteka je shranjena.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2246"/>
        <source>The file was printed successfully.</source>
        <translation>Datoteka je bila uspešno natisnjena.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="267"/>
        <source>Project website</source>
        <translation>Spletna stran projekta</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="264"/>
        <source>OpenTeacher helps you learn a foreign language vocabulary.</source>
        <translation>OpenTeacher vam pomaga pri učenju slovnice tujega jezika.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="996"/>
        <source>een = one</source>
        <translation>een = ena</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="996"/>
        <source>twee = two</source>
        <translation>twee = dve</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="996"/>
        <source>drie = three</source>
        <translation>drie = tri</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="384"/>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="384"/>
        <source>This credentials are saved in plain text on your harddrive.</source>
        <translation>Te poverilnice se shranijo kot golo besedilo na trdem disku vašega računalnika.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="384"/>
        <source>Don&apos;t use this function on a public computer!</source>
        <translation>Ne uporabljajte te funkcije na javnih računalnikih!</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2004"/>
        <source>Open...</source>
        <translation>Odpri ...</translation>
    </message>
</context>
<context>
    <name>OpenTeacherError</name>
    <message>
        <location filename="src/errors.py" line="35"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
</context>
<context>
    <name>QDialogButtonBox</name>
    <message>
        <location filename="src/openteacher.py" line="201"/>
        <source>Close without Saving</source>
        <translation>Zapri brez shranjevanja</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="188"/>
        <source>&amp;OK</source>
        <translation>&amp;V redu</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="190"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Prekliči</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="196"/>
        <source>&amp;Save</source>
        <translation>&amp;Shrani</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="192"/>
        <source>&amp;Yes</source>
        <translation>&amp;Da</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="193"/>
        <source>&amp;No</source>
        <translation>&amp;Ne</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="187"/>
        <source>OK</source>
        <translation>Vredu</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="189"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="195"/>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="197"/>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="198"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="199"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="202"/>
        <source>Don&apos;t save</source>
        <translation>Ne shrani</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="203"/>
        <source>Discard</source>
        <translation>Zavrži</translation>
    </message>
</context>
<context>
    <name>QShortcut</name>
    <message>
        <location filename="src/openteacher.py" line="206"/>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="207"/>
        <source>Return</source>
        <translation>Vrni</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="208"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="209"/>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
</context>
<context>
    <name>SaveError</name>
    <message>
        <location filename="src/errors.py" line="71"/>
        <source>Could not save file. Please check that the filename is correct and that you have permission to write to the save location.</source>
        <translation>Datoteke ni mogoče shraniti. Prosimo, preverite, če je ime datoteke zapisano pravilno in če imate dovoljenje, da shranjujete na izbrano lokacijo</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="src/openteacher.py" line="526"/>
        <source>Restart please</source>
        <translation>Prosimo, zaženite znova</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="497"/>
        <source>Connection to WRTS failed</source>
        <translation>Povezava na WRTS je spodletela</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="500"/>
        <source>Connection to WRTS succeeded</source>
        <translation>Povezava na WRTS je uspela.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="526"/>
        <source>You changed the language. In order to use the newly selected language, you need to restart OpenTeacher.</source>
        <translation>Zamenjali ste jezik. Če želite uporabljati izbran jezik, morate ponovno zagnati OpenTeacher.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="src/openteacher.py" line="411"/>
        <source>Make your choice</source>
        <translation>Izberite željeno</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="412"/>
        <source>System default</source>
        <translation>Privzeto s strani sistema</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="460"/>
        <source>Make your choice (all examples are good to bad)</source>
        <translation>Izberite željeno (vsi odgovori so si enakovredni)</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="461"/>
        <source>Percents</source>
        <translation>Odstotkov</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="462"/>
        <source>Dutch</source>
        <translation>Nizozemsko</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="463"/>
        <source>American</source>
        <translation>Ameriško (angleško)</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="464"/>
        <source>German</source>
        <translation>Nemško</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="465"/>
        <source>French</source>
        <translation>Francosko</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="466"/>
        <source>ECTS</source>
        <translation>ECTS</translation>
    </message>
</context>
<context>
    <name>UnsupportedFileExportError</name>
    <message>
        <location filename="src/errors.py" line="67"/>
        <source>Could not save file. Please specify a valid file extension.</source>
        <translation>Datoteke ni mogoče shraniti. Prosimo, navedite veljavno pripono datoteke.</translation>
    </message>
</context>
<context>
    <name>UnsupportedFileImportError</name>
    <message>
        <location filename="src/errors.py" line="47"/>
        <source>File couldn&apos;t be opened. Unsupported extension.</source>
        <translation>Datoteke ni mogoče odpreti. Neveljavna pripona datoteke.</translation>
    </message>
</context>
<context>
    <name>WordListTableModel</name>
    <message>
        <location filename="src/openteacher.py" line="661"/>
        <source>Question</source>
        <translation>Vprašanje</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="662"/>
        <source>Answer</source>
        <translation>Odgovor</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="663"/>
        <source>Second Answer (optional)</source>
        <translation>Drug odgovor (izbirno)</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="664"/>
        <source>Errors</source>
        <translation>Napake</translation>
    </message>
</context>
<context>
    <name>WrtsConnectionError</name>
    <message>
        <location filename="src/errors.py" line="83"/>
        <source>WRTS didn&apos;t accept the connection. Are you sure that your internet connection works and WRTS is online?</source>
        <translation>WRTS ni prejel povezave. Ali ste prepričani, da vaša internetna povezava deluje in da ste povezani na WRTS?</translation>
    </message>
</context>
<context>
    <name>WrtsLoginError</name>
    <message>
        <location filename="src/errors.py" line="39"/>
        <source>WRTS didn&apos;t accept the login credentials. Are you sure you entered your e-mail and password correctly?</source>
        <translation>WRTS ni sprejel poverilnice za prijavo. Ste prepričani, da sta e-pošta in geslo pravilna?</translation>
    </message>
</context>
</TS>
